@@ -216,8 +216,8 @@ static volatile jmp_buf      mctx_trampoline;
 static volatile pth_mctx_t   mctx_caller;
 static volatile sig_atomic_t mctx_called;
 
-static volatile pth_mctx_t  *mctx_creating;
-static volatile void       (*mctx_creating_func)(void);
+static pth_mctx_t * volatile mctx_creating;
+static      void (* volatile mctx_creating_func)(void);
 static volatile sigset_t     mctx_creating_sigs;
 
 static void pth_mctx_set_trampoline(int);
@@ -343,8 +343,8 @@ intern int pth_mctx_set(
      * Tell the trampoline and bootstrap function where to dump
      * the new machine context, and what to do afterwards...
      */
-    mctx_creating      = (volatile pth_mctx_t *)mctx;
-    mctx_creating_func = (volatile void (*)(void))func;
+    mctx_creating      = mctx;
+    mctx_creating_func = func;
     memcpy((void *)&mctx_creating_sigs, &osigs, sizeof(sigset_t));
 
     /*
@@ -410,8 +410,8 @@ static void pth_mctx_set_trampoline(int sig)
 /* boot function */
 static void pth_mctx_set_bootstrap(void)
 {
-    volatile pth_mctx_t *mctx_starting;
-    volatile void (*mctx_starting_func)(void);
+    pth_mctx_t * volatile mctx_starting;
+    void (* volatile mctx_starting_func)(void);
 
     /*
      * Switch to the final signal mask (inherited from parent)
